@@ -19,7 +19,9 @@ rename. <- function(.data, ...) {
 }
 
 #' @export
-rename..tidytable <- function(.data, ...) {
+rename..data.frame <- function(.data, ...) {
+
+  .data <- as_tidytable(.data)
 
   dots <- enexprs(...)
   .data <- shallow(.data)
@@ -32,13 +34,6 @@ rename..tidytable <- function(.data, ...) {
   .data
 }
 
-#' @export
-rename..data.frame <- function(.data, ...) {
-  .data <- as_tidytable(.data)
-
-  rename.(.data, ...)
-}
-
 #' @export
 #' @rdname rename.
 dt_rename <- rename.
