@@ -39,34 +39,25 @@ slice. <- function(.data, rows = 1:5, by = NULL) {
 }
 
 #' @export
-slice..tidytable <- function(.data, rows = 1:5, by = NULL) {
+slice..data.frame <- function(.data, rows = 1:5, by = NULL) {
+
+  .data <- as_tidytable(.data)
 
   rows <- enexpr(rows) # Needed so 1:.N works
   by <- enexpr(by)
+  by <- vec_selector_by(.data, !!by)
 
   if (is.null(by)) {
     eval_expr(
       .data[!!rows]
     )
   } else {
-    by <- vec_selector_by(.data, !!by)
-
     eval_expr(
       .data[, .SD[!!rows], !!by]
     )
   }
 }
 
-#' @export
-slice..data.frame <- function(.data, rows = 1:5, by = NULL) {
-
-  .data <- as_tidytable(.data)
-  rows <- enexpr(rows)
-  by <- enexpr(by)
-
-  slice.(.data, rows = !!rows, by = !!by)
-}
-
 #' @export
 #' @rdname slice.
 slice_head. <- function(.data, n = 5, by = NULL) {
@@ -74,7 +65,9 @@ slice_head. <- function(.data, n = 5, by = NULL) {
 }
 
 #' @export
-slice_head..tidytable <- function(.data, n = 5, by = NULL) {
+slice_head..data.frame <- function(.data, n = 5, by = NULL) {
+
+  .data <- as_tidytable(.data)
 
   n <- enexpr(n)
   by <- enexpr(by)
@@ -85,16 +78,6 @@ slice_head..tidytable <- function(.data, n = 5, by = NULL) {
   )
 }
 
-#' @export
-slice_head..data.frame <- function(.data, n = 5, by = NULL) {
-
-  .data <- as_tidytable(.data)
-  n <- enexpr(n)
-  by <- enexpr(by)
-
-  slice_head.(.data, n = !!n, by = !!by)
-}
-
 #' @export
 #' @rdname slice.
 slice_tail. <- function(.data, n = 5, by = NULL) {
@@ -102,7 +85,9 @@ slice_tail. <- function(.data, n = 5, by = NULL) {
 }
 
 #' @export
-slice_tail..tidytable <- function(.data, n = 5, by = NULL) {
+slice_tail..data.frame <- function(.data, n = 5, by = NULL) {
+
+  .data <- as_tidytable(.data)
 
   n <- enexpr(n)
   by <- enexpr(by)
@@ -113,16 +98,6 @@ slice_tail..tidytable <- function(.data, n = 5, by = NULL) {
   )
 }
 
-#' @export
-slice_tail..data.frame <- function(.data, n = 5, by = NULL) {
-
-  .data <- as_tidytable(.data)
-  n <- enexpr(n)
-  by <- enexpr(by)
-
-  slice_tail.(.data, n = !!n, by = !!by)
-}
-
 #' @export
 #' @rdname slice.
 slice_max. <- function(.data, order_by, n = 1, by = NULL) {
@@ -131,7 +106,8 @@ slice_max. <- function(.data, order_by, n = 1, by = NULL) {
 
 #' @export
 slice_max..data.frame <- function(.data, order_by, n = 1, by = NULL) {
-  if (!is_tidytable(.data)) .data <- as_tidytable(.data)
+
+  .data <- as_tidytable(.data)
 
   if (missing(order_by)) stop("order_by must be supplied")
 
@@ -152,7 +128,8 @@ slice_min. <- function(.data, order_by, n = 1, by = NULL) {
 
 #' @export
 slice_min..data.frame <- function(.data, order_by, n = 1, by = NULL) {
-  if (!is_tidytable(.data)) .data <- as_tidytable(.data)
+
+  .data <- as_tidytable(.data)
 
   if (missing(order_by)) stop("order_by must be supplied")
 
