@@ -27,8 +27,9 @@ top_n. <- function(.data, n = 5, wt = NULL, by = NULL) {
 }
 
 #' @export
-top_n..tidytable <- function(.data, n = 5, wt = NULL, by = NULL) {
+top_n..data.frame <- function(.data, n = 5, wt = NULL, by = NULL) {
 
+  .data <- as_tidytable(.data)
   n <- enexpr(n)
   wt <- enexpr(wt)
   by <- enexpr(by)
@@ -40,17 +41,6 @@ top_n..tidytable <- function(.data, n = 5, wt = NULL, by = NULL) {
   }
 }
 
-#' @export
-top_n..data.frame <- function(.data, n = 5, wt = NULL, by = NULL) {
-
-  .data <- as_tidytable(.data)
-  n < enexpr(n)
-  wt <- enexpr(wt)
-  by <- enexpr(by)
-
-  top_n.(.data, !!n, wt = !!wt, by = !!by)
-}
-
 #' @export
 #' @rdname top_n.
 dt_top_n <- top_n.
