@@ -8,7 +8,7 @@ test_that("dt_ifelse works", {
   expect_equal(df$new_col, c(0,1,NA,NA))
 })
 
-test_that("ifelse. works", {
+test_that("ifelse. works with true = NA", {
 
   df <- tidytable(x = 1:4)
 
@@ -17,3 +17,13 @@ test_that("ifelse. works", {
 
   expect_equal(df$new_col, c(0,1,NA,NA))
 })
+
+test_that("ifelse. works with false = NA", {
+
+  df <- tidytable(x = 1:4)
+
+  df <- df %>%
+    dt_mutate(new_col = ifelse.(x > 2L, x - 1L, NA))
+
+  expect_equal(df$new_col, c(NA,NA,2,3))
+})
