@@ -1,4 +1,4 @@
-test_that("rename() works for one column", {
+test_that("dt_() works for one column", {
   df <- data.table(x = c(1,1,1), y = c(2,2,2), z = c("a", "a", "b"))
   df <- df %>%
     dt_rename(new_x = x)
@@ -6,19 +6,35 @@ test_that("rename() works for one column", {
   expect_named(df, c("new_x", "y", "z"))
 })
 
-test_that("rename() works for one column w/ data.frame", {
+test_that("rename.() works for one column", {
+  df <- data.table(x = c(1,1,1), y = c(2,2,2), z = c("a", "a", "b"))
+  df <- df %>%
+    rename.(new_x = x)
+
+  expect_named(df, c("new_x", "y", "z"))
+})
+
+test_that("rename.() doesn't modify-by-reference", {
+  df <- data.table(x = c(1,1,1), y = c(2,2,2), z = c("a", "a", "b"))
+  df %>%
+    rename.(new_x = x)
+
+  expect_named(df, c("x", "y", "z"))
+})
+
+test_that("rename.() works for one column w/ data.frame", {
   df <- data.frame(x = c(1,1,1), y = c(2,2,2), z = c("a", "a", "b"))
   df <- df %>%
-    dt_rename(new_x = x)
+    rename.(new_x = x)
 
   expect_named(df, c("new_x", "y", "z"))
 })
 
-test_that("rename() works for multiple columns", {
+test_that("rename.() works for multiple columns", {
   df <- data.table(x = c(1,1,1), y = c(2,2,2), z = c("a", "a", "b"))
   df <- df %>%
-    dt_rename(new_x = x,
-              new_y = y)
+    rename.(new_x = x,
+            new_y = y)
 
   expect_named(df, c("new_x", "new_y", "z"))
 })
@@ -26,7 +42,7 @@ test_that("rename() works for multiple columns", {
 test_that("rename_if() works with predicate", {
   df <- data.table(x = c(1,1,1), y = c(2,2,2), z = c("a", "a", "b"))
   df <- df %>%
-    dt_rename_if(is.character, function(.x) paste0(.x, "_character"))
+    rename_if.(is.character, function(.x) paste0(.x, "_character"))
 
   expect_named(df, c("x","y","z_character"))
 })
@@ -34,7 +50,7 @@ test_that("rename_if() works with predicate", {
 test_that("rename_at(): .vars works with select helpers in c()", {
   df <- data.table(x_start = c(1,1,1), end_x = c(2,2,2), z = c("a", "a", "b"))
   df <- df %>%
-    dt_rename_at(c(dt_starts_with("x")), function(.x) paste0(.x, "_append"))
+    rename_at.(c(dt_starts_with("x")), function(.x) paste0(.x, "_append"))
 
   expect_named(df, c("x_start_append", "end_x", "z"))
 })
@@ -42,7 +58,7 @@ test_that("rename_at(): .vars works with select helpers in c()", {
 test_that("rename_at() works for range selection", {
   df <- data.table(x = c(1,1,1), y = c(2,2,2), z = c("a", "a", "b"))
   df <- df %>%
-    dt_rename_at(c(x:y), function(.x) paste0(.x, "_append"))
+    rename_at.(c(x:y), function(.x) paste0(.x, "_append"))
 
   expect_named(df, c("x_append", "y_append", "z"))
 })
@@ -50,7 +66,7 @@ test_that("rename_at() works for range selection", {
 test_that("rename_all() works for all variables", {
   df <- data.table(x = c(1,1,1), y = c(2,2,2))
   df <- df %>%
-    dt_rename_all(function(.x) paste0(.x, "_append"))
+    rename_all.(function(.x) paste0(.x, "_append"))
 
   expect_named(df, c("x_append", "y_append"))
 })
@@ -58,38 +74,36 @@ test_that("rename_all() works for all variables", {
 test_that("rename_all() works for all variables w/ data.frame", {
   df <- data.frame(x = c(1,1,1), y = c(2,2,2))
   df <- df %>%
-    dt_rename_all(function(.x) paste0(.x, "_append"))
+    rename_all.(function(.x) paste0(.x, "_append"))
 
   expect_named(df, c("x_append", "y_append"))
 })
 
-# twiddle testing -----------------------------------
-test_that("rename_if() works with twiddle", {
+test_that("rename_with() works for all variables", {
+  df <- data.table(x = c(1,1,1), y = c(2,2,2))
+  df <- df %>%
+    rename_with.(~ paste0(.x, "_append"))
+
+  expect_named(df, c("x_append", "y_append"))
+})
+
+test_that("rename_with() works for all variables w/ data.frame", {
+  df <- data.frame(x = c(1,1,1), y = c(2,2,2))
+  df <- df %>%
+    rename_with.(~ paste0(.x, "_append"))
+
+  expect_named(df, c("x_append", "y_append"))
+})
+
+test_that("rename_if() works with predicate", {
   df <- data.table(x = c(1,1,1), y = c(2,2,2), z = c("a", "a", "b"))
-  anon_df <- df %>%
-    as_tidytable() %>%
-    dt_rename_if(is.character, function(.x) paste0(.x, "_character"))
-  twiddle_df <- df %>%
-    as_tidytable() %>%
-    dt_rename_if(is.character, ~ paste0(.x, "_character"))
+  df <- df %>%
+    rename_with.(~ paste0(.x, "_character"), is.character)
 
-  expect_named(twiddle_df, c("x","y","z_character"))
-  expect_equal(anon_df, twiddle_df)
-})
-
-test_that("rename_at() works with twiddle", {
-  df <- data.table(x_start = c(1,1,1), end_x = c(2,2,2), z = c("a", "a", "b"))
-  anon_df <- df %>%
-    as_tidytable() %>%
-    dt_rename_at(c(dt_starts_with("x")), ~ paste0(.x, "_append"))
-  twiddle_df <- df %>%
-    as_tidytable() %>%
-    dt_rename_at(c(dt_starts_with("x")), ~ paste0(.x, "_append"))
-
-  expect_named(twiddle_df, c("x_start_append", "end_x", "z"))
-  expect_equal(anon_df, twiddle_df)
+  expect_named(df, c("x","y","z_character"))
 })
 
+# twiddle testing -----------------------------------
 test_that("rename_across() works with twiddle", {
   df <- data.table(x_start = c(1,1,1), end_x = c(2,2,2), z = c("a", "a", "b"))
   anon_df <- df %>%
