@@ -1,7 +1,7 @@
-test_that("works on numeric columns", {
+test_that("dt_ works on numeric columns", {
   test_df <- data.table(x = c(1, 2, NA), y = c("a", NA, "c"))
   replaced_df <- test_df %>%
-    dt_mutate(x = dt_replace_na(x, 5))
+    mutate.(x = dt_replace_na(x, 5))
 
   expect_equal(replaced_df$x, c(1,2,5))
 })
@@ -9,7 +9,15 @@ test_that("works on numeric columns", {
 test_that("works on numeric columns", {
   test_df <- data.table(x = c(1, 2, NA), y = c("a", NA, "c"))
   replaced_df <- test_df %>%
-    dt_mutate(y = dt_replace_na(y, "b"))
+    mutate.(x = replace_na.(x, 5))
+
+  expect_equal(replaced_df$x, c(1,2,5))
+})
+
+test_that("works on character columns", {
+  test_df <- data.table(x = c(1, 2, NA), y = c("a", NA, "c"))
+  replaced_df <- test_df %>%
+    mutate.(y = replace_na.(y, "b"))
 
   expect_equal(replaced_df$y, c("a", "b", "c"))
 })
