@@ -47,3 +47,12 @@ test_that("works with predicates", {
 
   expect_named(df, c("x", "y"))
 })
+
+test_that("can rename columns & doesn't modify by reference", {
+  df <- data.table(x = c(1,1,1), y = c(2,2,2), z = c("a", "a", "b"))
+  new_df <- df %>%
+    select.(new = x, y, stuff = z)
+
+  expect_named(df, c("x", "y", "z"))
+  expect_named(new_df, c("new", "y", "stuff"))
+})
