@@ -42,13 +42,30 @@ test_that("can do group aggregation with no by", {
   expect_equal(tidytable_df, datatable_df)
 })
 
-test_that("can do group aggregation with by list()", {
+# test_that("can do group aggregation with by list()", {
+#   df <- tidytable(x = 1:4, y = c("a","a","a","b"))
+#
+#   tidytable_df <- df %>%
+#     summarize.(avg_x = mean(x), by = list(y))
+#
+#   datatable_df <- df[, list(avg_x = mean(x)), by = y]
+#
+#   expect_equal(tidytable_df, datatable_df)
+# })
+
+test_that("by = list() causes an error", {
   df <- tidytable(x = 1:4, y = c("a","a","a","b"))
 
-  tidytable_df <- df %>%
-    summarize.(avg_x = mean(x), by = list(y))
+  expect_error(summarize.(df, avg_x = mean(x), by = list(y)))
+})
 
-  datatable_df <- df[, list(avg_x = mean(x)), by = y]
+test_that("by = list works for column named list", {
+  df <- tidytable(x = 1:4, list = c("a","a","a","b"))
+
+  tidytable_df <- df %>%
+    summarize.(avg_x = mean(x), by = list)
+
+  datatable_df <- df[, list(avg_x = mean(x)), by = list]
 
   expect_equal(tidytable_df, datatable_df)
 })
